==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/kio/kio/directorysizejob.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2000, 2006 David Faure <faure@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef DIRECTORYSIZEJOB_H
#define DIRECTORYSIZEJOB_H

#include <kio/job.h>
#include <kfileitem.h>

namespace KIO {

/**
 * Computes a directory size (similar to "du", but doesn't give the same results
 * since we simply sum up the dir and file sizes, whereas du speaks disk blocks)
 */
class KIO_EXPORT DirectorySizeJob : public KIO::Job
{
    Q_OBJECT

public:
    /**
     * Do not create a DirectorySizeJob directly. Use KIO::directorySize() instead.
     * instead.
     */
    DirectorySizeJob( const KUrl & directory );
    /**
     * Do not create a DirectorySizeJob directly. Use KIO::directorySize() instead.
     * instead.
     */
    DirectorySizeJob( const KFileItemList & lstItems );

    ~DirectorySizeJob();

public:
    /**
     * @return the size we found
     */
    KIO::filesize_t totalSize() const { return m_totalSize; }

    /**
     * @return the total number of files (counting symlinks to files, sockets
     * and character devices as files) in this directory and all sub-directories
     */
    KIO::filesize_t totalFiles() const { return m_totalFiles; }

    /**
     * @return the total number of sub-directories found (not including the
     * directory the search started from and treating symlinks to directories
     * as directories)
     */
    KIO::filesize_t totalSubdirs() const { return m_totalSubdirs; }

private:
    void startNextJob( const KUrl & url );

private Q_SLOTS:
    virtual void slotResult( KJob *job );
    void slotEntries( KIO::Job * , const KIO::UDSEntryList &);
    void processNextItem();

private:
    KIO::filesize_t m_totalSize;
    KIO::filesize_t m_totalFiles;
    KIO::filesize_t m_totalSubdirs;
    KFileItemList m_lstItems;
    int m_currentItem;
private:
    class DirectorySizeJobPrivate* d;
};

/**
 * Computes a directory size (by doing a recursive listing).
 * Connect to the result signal. Use NetAccess::synchronousRun for a synchronous version.
 *
 * This one lists a single directory.
 */
KIO_EXPORT DirectorySizeJob * directorySize( const KUrl & directory );

/**
 * Computes a directory size (by doing a recursive listing).
 * Connect to the result signal. Use NetAccess::synchronousRun for a synchronous version.
 *
 * This one lists the items from @p lstItems.
 * The reason we asks for items instead of just urls, is so that
 * we directly know if the item is a file or a directory,
 * and in case of a file, we already have its size.
 */
KIO_EXPORT DirectorySizeJob * directorySize( const KFileItemList & lstItems );

}

#endif

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kio/kio/directorysizejob.h <==
/* This file is part of the KDE libraries
    Copyright (C) 2000, 2006 David Faure <faure@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef DIRECTORYSIZEJOB_H
#define DIRECTORYSIZEJOB_H

#include "job.h"
#include <kfileitem.h>

namespace KIO {

class DirectorySizeJobPrivate;
/**
 * Computes a directory size (similar to "du", but doesn't give the same results
 * since we simply sum up the dir and file sizes, whereas du speaks disk blocks)
 */
class KIO_EXPORT DirectorySizeJob : public KIO::Job
{
    Q_OBJECT

public:
    ~DirectorySizeJob();

public:
    /**
     * @return the size we found
     */
    KIO::filesize_t totalSize() const;

    /**
     * @return the total number of files (counting symlinks to files, sockets
     * and character devices as files) in this directory and all sub-directories
     */
    KIO::filesize_t totalFiles() const;

    /**
     * @return the total number of sub-directories found (not including the
     * directory the search started from and treating symlinks to directories
     * as directories)
     */
    KIO::filesize_t totalSubdirs() const;

protected Q_SLOTS:
    virtual void slotResult( KJob *job );

protected:
    DirectorySizeJob(DirectorySizeJobPrivate &dd);

private:
    Q_PRIVATE_SLOT(d_func(), void slotEntries( KIO::Job * , const KIO::UDSEntryList &))
    Q_PRIVATE_SLOT(d_func(), void processNextItem())
    Q_DECLARE_PRIVATE(DirectorySizeJob)
};

/**
 * Computes a directory size (by doing a recursive listing).
 * Connect to the result signal. Use NetAccess::synchronousRun for a synchronous version.
 *
 * This one lists a single directory.
 */
KIO_EXPORT DirectorySizeJob * directorySize( const KUrl & directory );

/**
 * Computes a directory size (by doing a recursive listing).
 * Connect to the result signal. Use NetAccess::synchronousRun for a synchronous version.
 *
 * This one lists the items from @p lstItems.
 * The reason we asks for items instead of just urls, is so that
 * we directly know if the item is a file or a directory,
 * and in case of a file, we already have its size.
 */
KIO_EXPORT DirectorySizeJob * directorySize( const QList<KFileItem> & lstItems );

}

#endif
